==> estateplat-common-1.2.4-20240603.064043-1236-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxSfxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/4/8
 * @description 收费信息
 */
@Table(name = "GX_WW_SQXX_SFXX")
public class GxWwSqxxSfxx {
    @Id
    private String sfxxid;
    private Double hj;//合计
    private String qlrlb;//权利人类别
    private String qlrmc;//权利人名称
    private String sqxxid;
    private String sfkp;//是否开票
    private String jfzt;//缴费状态 0：未缴费  1：已缴费
    private String sfjzjf;//是否集中缴费 0：否 1：是
    private String businessnumber;//缴款书号(收费流水号)
    private String czjkm;//财政缴款码
    private String pjdz;//票据地址
    private String jksbm;//缴款识别码
    private String xmid;//项目id（收费信息需要对应主项目存xmid）

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlb) {
        this.qlrlb = qlrlb;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }


    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSfkp() {
        return sfkp;
    }

    public void setSfkp(String sfkp) {
        this.sfkp = sfkp;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }

    public String getBusinessnumber() {
        return businessnumber;
    }

    public void setBusinessnumber(String businessnumber) {
        this.businessnumber = businessnumber;
    }

    public String getCzjkm() {
        return czjkm;
    }

    public void setCzjkm(String czjkm) {
        this.czjkm = czjkm;
    }

    public String getPjdz() {
        return pjdz;
    }

    public void setPjdz(String pjdz) {
        this.pjdz = pjdz;
    }

    public String getJksbm() {
        return jksbm;
    }

    public void setJksbm(String jksbm) {
        this.jksbm = jksbm;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }
}

==> estateplat-common-1.2.4-20251010.062031-1310-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxWwSqxxSfxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version V1.0, 2021/4/8
 * @description 收费信息
 */
@Table(name = "GX_WW_SQXX_SFXX")
public class GxWwSqxxSfxx {
    @Id
    private String sfxxid;
    private Double hj;//合计
    private String qlrlb;//权利人类别
    private String qlrmc;//权利人名称
    private String sqxxid;
    private String sfkp;//是否开票
    private String jfzt;//缴费状态 0：未缴费  1：已缴费
    private String sfjzjf;//是否集中缴费 0：否 1：是
    private String businessnumber;//缴款书号(收费流水号)
    private String czjkm;//财政缴款码
    private String pjdz;//票据地址
    private String jksbm;//缴款识别码
    private String xmid;//项目id（收费信息需要对应主项目存xmid）
    private Date jfsj;//缴费时间

    public String getSfxxid() {
        return sfxxid;
    }

    public void setSfxxid(String sfxxid) {
        this.sfxxid = sfxxid;
    }

    public Double getHj() {
        return hj;
    }

    public void setHj(Double hj) {
        this.hj = hj;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlb) {
        this.qlrlb = qlrlb;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }


    public String getSqxxid() {
        return sqxxid;
    }

    public void setSqxxid(String sqxxid) {
        this.sqxxid = sqxxid;
    }

    public String getSfkp() {
        return sfkp;
    }

    public void setSfkp(String sfkp) {
        this.sfkp = sfkp;
    }

    public String getJfzt() {
        return jfzt;
    }

    public void setJfzt(String jfzt) {
        this.jfzt = jfzt;
    }

    public String getSfjzjf() {
        return sfjzjf;
    }

    public void setSfjzjf(String sfjzjf) {
        this.sfjzjf = sfjzjf;
    }

    public String getBusinessnumber() {
        return businessnumber;
    }

    public void setBusinessnumber(String businessnumber) {
        this.businessnumber = businessnumber;
    }

    public String getCzjkm() {
        return czjkm;
    }

    public void setCzjkm(String czjkm) {
        this.czjkm = czjkm;
    }

    public String getPjdz() {
        return pjdz;
    }

    public void setPjdz(String pjdz) {
        this.pjdz = pjdz;
    }

    public String getJksbm() {
        return jksbm;
    }

    public void setJksbm(String jksbm) {
        this.jksbm = jksbm;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }
}
